summaryrefslogtreecommitdiff
path: root/src/gui/gui.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/gui/gui.h')
-rw-r--r--src/gui/gui.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/src/gui/gui.h b/src/gui/gui.h
index a29d02b7..b3c989c2 100644
--- a/src/gui/gui.h
+++ b/src/gui/gui.h
@@ -103,7 +103,8 @@ extern LexSkin gui_skin;
extern BITMAP *gui_bitmap;
extern ALFONT_FONT *gui_font;
-extern gcn::Container* guitop; // The top container
+extern gcn::Container* guiTop; // The top container
+extern gcn::AllegroGraphics* guiGraphics; // Graphics driver
/* Definition of the callback function prototypes */
typedef int (*gui_buttonCallback)(int id);